==> haskell-concurrent-output-1.10.11-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-concurrent-output.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 concurrent-output
version:              1.10.11
visibility:           public
id:                   concurrent-output-1.10.11-CCmEvlzwxr1LbYcXZ6uhhF
key:                  concurrent-output-1.10.11-CCmEvlzwxr1LbYcXZ6uhhF
license:              BSD-2-Clause
copyright:            2015-2017 Joey Hess, 2009 Joachim Breitner
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess, Joachim Breitner
stability:            Stable
synopsis:             Ungarble output from several threads or commands
description:
    Lets multiple threads and external processes concurrently output to the
    console, without it getting all garbled up.

    Built on top of that is a way of defining multiple output regions,
    which are automatically laid out on the screen and can be individually
    updated by concurrent threads. Can be used for progress displays etc.

    <<https://joeyh.name/code/concurrent-output/demo2.gif>>

category:             User Interfaces
abi:                  63909e13d648e1b9a4be45c438a98dcc
exposed:              True
exposed-modules:
    System.Console.Concurrent System.Console.Concurrent.Internal
    System.Console.Regions System.Process.Concurrent

hidden-modules:       Utility.Monad Utility.Data Utility.Exception
import-dirs:          /usr/lib/ghc-8.8.1/site-local/concurrent-output-1.10.11
library-dirs:         /usr/lib/ghc-8.8.1/site-local/concurrent-output-1.10.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/concurrent-output-1.10.11
hs-libraries:         HSconcurrent-output-1.10.11-CCmEvlzwxr1LbYcXZ6uhhF
depends:
    ansi-terminal-0.10.2-HhJCIibw6rY8DtJJgZqOOO
    async-2.2.2-JbTI50oMvRQ99Orc9hydUg base-4.13.0.0 directory-1.3.3.2
    exceptions-0.10.4-95dT6gGLwmF7bZDhSZRBfb process-1.6.5.1
    stm-2.5.0.0 terminal-size-0.3.2.1-Lp3EPz6AmPvE7uvVvixMVf
    text-1.2.4.0 transformers-0.5.6.2 unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-concurrent-output/html/concurrent-output.haddock

haddock-html:         /usr/share/doc/haskell-concurrent-output/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concurrent-output-1.10.11-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-concurrent-output.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 concurrent-output
version:              1.10.11
visibility:           public
id:                   concurrent-output-1.10.11-7smmdf3S0Ax36SDDAbjoWs
key:                  concurrent-output-1.10.11-7smmdf3S0Ax36SDDAbjoWs
license:              BSD-2-Clause
copyright:            2015-2017 Joey Hess, 2009 Joachim Breitner
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess, Joachim Breitner
stability:            Stable
synopsis:             Ungarble output from several threads or commands
description:
    Lets multiple threads and external processes concurrently output to the
    console, without it getting all garbled up.

    Built on top of that is a way of defining multiple output regions,
    which are automatically laid out on the screen and can be individually
    updated by concurrent threads. Can be used for progress displays etc.

    <<https://joeyh.name/code/concurrent-output/demo2.gif>>

category:             User Interfaces
abi:                  0ef4c8c3348771022d30c8719fc4a35b
exposed:              True
exposed-modules:
    System.Console.Concurrent System.Console.Concurrent.Internal
    System.Console.Regions System.Process.Concurrent

hidden-modules:       Utility.Monad Utility.Data Utility.Exception
import-dirs:          /usr/lib/ghc-8.8.2/site-local/concurrent-output-1.10.11
library-dirs:         /usr/lib/ghc-8.8.2/site-local/concurrent-output-1.10.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/concurrent-output-1.10.11
hs-libraries:         HSconcurrent-output-1.10.11-7smmdf3S0Ax36SDDAbjoWs
depends:
    ansi-terminal-0.10.3-9zJT3Osp5wTAaMBIHKdPu2
    async-2.2.2-26QXzOS0mu2H7YxyeMvEdZ base-4.13.0.0 directory-1.3.4.0
    exceptions-0.10.4-AcCA76Y0j0oK3rQoxPMQMv process-1.6.7.0
    stm-2.5.0.0 terminal-size-0.3.2.1-Lp3EPz6AmPvE7uvVvixMVf
    text-1.2.4.0 transformers-0.5.6.2 unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-concurrent-output/html/concurrent-output.haddock

haddock-html:         /usr/share/doc/haskell-concurrent-output/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
